#!/usr/bin/env python3
"""
This script takes 2 positional arguments, HOSTNAME and IP_ADDRESS.
It polls the Greenhost API for a VPS with the hostname HOSTNAME and checks if
that machine has the IP address provided in the second argument. If
everything's OK, the machine can be reused for the current CI pipeline and the
script exits with 0. If the machine can't be reused the script exits with 1
"""

import sys
import greenhost_cloud

HOSTNAME = sys.argv[1]
IP_ADDRESS = sys.argv[2]
MACHINES = greenhost_cloud.get_droplets_by_name("^{}$".format(HOSTNAME))

if MACHINES == []:
    print("No machines found with hostname {}".format(HOSTNAME))
    sys.exit(1)

for machine in MACHINES:
    print("Machine status is {}".format(machine['status']))
    print("Comparing IP address '{}' with IP address '{}'".format(
        machine['networks']['v4'][0]['ip_address'], IP_ADDRESS))
    if machine['status'] == 'running' and \
            machine['networks']['v4'][0]['ip_address'] == IP_ADDRESS:
        sys.exit(0)
sys.exit(1)
